@@ -43,7 +43,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.033_01';
+our $VERSION = '0.039_01';
 
 use base qw{Astro::Coord::ECI};
 
@@ -490,7 +490,7 @@ eod
 
 #	Coordinates of Moon (finally!)
 
-    my $lambda = deg2rad ($sigmal / 1_000_000) + $Lprime;
+    my $lambda = mod2pi( deg2rad ($sigmal / 1_000_000) + $Lprime );
     my $beta = deg2rad ($sigmab / 1_000_000);
     my $delta = $sigmar / 1000 + 385_000.56;
 
@@ -530,7 +530,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2010, Thomas R. Wyant, III
+Copyright (C) 2005-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
