@@ -121,7 +121,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.033_01';
+our $VERSION = '0.039_01';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -147,26 +147,29 @@ my %mutator = (
 	$_[0]->{&ATTRIBUTE_KEY}{_algorithm_method} = $method;
 	},
     );
-foreach my $key (qw{am day extinction max_mirror_angle pm status}) {
+foreach my $key (qw{am day extinction max_mirror_angle pm status zone}) {
     $mutator{$key} = sub {$_[0]->{&ATTRIBUTE_KEY}{$_[1]} = $_[2]};
-    }
+}
+
 my %accessor = ();
 foreach my $key (keys %mutator) {
     $accessor{$key} ||= sub {$_[0]->{&ATTRIBUTE_KEY}{$_[1]}}
-    }
+}
 
 my %static = (		# static values
-	algorithm => 'fixed',
-	am => 1,
-	day => 1,
-	extinction => 1,
-	max_mirror_angle => DEFAULT_MAX_MIRROR_ANGLE,
-	pm => 1,
-	status => '',
-    );
+    algorithm => 'fixed',
+    am => 1,
+    day => 1,
+    extinction => 1,
+    max_mirror_angle => DEFAULT_MAX_MIRROR_ANGLE,
+    pm => 1,
+    status => '',
+    zone	=> undef,	# Offset from GMT, in seconds
+);
+
 my %statatr = (		# for convenience of get() and put().
     &ATTRIBUTE_KEY => \%static,
-    );
+);
 
 __PACKAGE__->alias (iridium => __PACKAGE__);
 
@@ -269,7 +272,9 @@ eod
 
 sub attribute {
     my ($self, $name) = @_;
-    return $mutator{$name} ? __PACKAGE__ : $self->SUPER::attribute ($name);
+    return exists $accessor{$name} ?
+	__PACKAGE__ :
+	$self->SUPER::attribute ($name);
 }
 
 
@@ -502,11 +507,9 @@ eod
 
     my @flares;
     my $illum = $self->get ('illum');
-    my $illum_radius = $illum->get ('diameter') / 2;
     my $horizon = $self->get ('horizon');
     my $twilight = $self->get ('twilight');
     $sun ||= Astro::Coord::ECI::Sun->new ();
-    my $height = ($station->geodetic)[2];
 
     my %want = (
 	am => $self->get ('am'),
@@ -574,7 +577,7 @@ eod
 
 #	Calculate whether satellite is above horizon.
 
-	my ($azm, $elev, $rng) = $station->azel ($self, 0);
+	my (undef, $elev, $rng) = $station->azel ($self, 0);
 	$elev > $horizon or next;
 
 
@@ -585,7 +588,7 @@ eod
 	    my $sun_elev = ($station->azel ($sun->universal ($time)))[1];
 	    ($want{day} && $sun_elev > $day_limit) and return 1;
 	    (($want{am} || $want{pm}) && $sun_elev < $night_limit) or return 0;
-	    my @local_time = localtime ($time);
+	    my @local_time = $self->_time_in_zone( $time );
 	    my $time_of_day = ($local_time[2] * 60 + $local_time[1]) * 60
 		    + $local_time[0];
 	    ($want{am} && ($time_of_day > AM_START_LIMIT ||
@@ -598,7 +601,8 @@ eod
 
 #	Calculate whether the satellite is illuminated.
 
-	my $lit = ($self->azel ($illum->universal ($time)))[1] >=
+##	my $lit = ($self->azel ($illum->universal ($time)))[1] >=
+	($self->azel ($illum->universal ($time)))[1] >=
 	    $self->dip () - $illum_tolerance or next;
 
 
@@ -837,7 +841,8 @@ MMA_LOOP:
 sub _flare_entrance {
     my ($self, $illum, $station, $mma, $start, $end) = @_;
     my $output;
-    my $time = find_first_true (
+#   my $time = find_first_true (
+    find_first_true (
 	$start, $end,
 	sub {
 	    $self->universal ($_[0]);
@@ -1120,7 +1125,7 @@ my $flare_mag = $limb_darkening > 0 ? do {
 
 my $sun_elev = ($station->azel ($sun->universal ($time)))[1];
 my $flare_type = $sun_elev >= $twilight ? 'day' :
-	(localtime $time)[2] > 12 ? 'pm' : 'am';
+	( $self->_time_in_zone( $time ) )[2] > 12 ? 'pm' : 'am';
 
 
 #	Compute the angle from the Sun to the flare.
@@ -1406,7 +1411,7 @@ sub _reflection_fixed {
 
 #	Calculate whether satellite is above horizon.
 
-    my ($azm, $elev, $rng) = $station->universal ($time)->
+    my (undef, $elev) = $station->universal ($time)->
 	    azel ($self->universal ($time), 0);
     return scalar _make_status (
 	sprintf ('Satellite %.2f degrees below horizon', rad2deg (-$elev)))
@@ -1480,6 +1485,22 @@ sub set {
     return $self;
 }
 
+# For use of -am and -pm
+sub _time_in_zone {
+    my ( $self, $time ) = @_;
+
+    defined( my $zone = $self->get( 'zone' ) )
+	or return localtime $time;
+
+    looks_like_number( $zone )
+	and return gmtime( $zone * 3600 + $time );
+
+    # TODO use DateTime if available
+
+    local $ENV{TZ} = $zone;
+    return localtime $time;
+}
+
 1;
 
 __END__
@@ -1515,6 +1536,26 @@ value Perl considers false (e.g. undef).
 
 The default is 1 (i.e. true).
 
+=item max_mirror_angle (angle in radians)
+
+This attribute is used in the flare calculation to screen passes for
+flare potential. The position of the satellite is calculated at
+intervals during a pass, and for each position the mirror angle (defined
+as the angle subtended at the satellite between the observer and the
+reflection of the Sun) is calculated. If no calculated mirror angle is
+less than the value of this attribute, no flare is predicted. If one of
+the mirror angles B<is> less than this, a flare is predicted and its
+maximum magnitude calculated.
+
+The default value is equivalent to 10 degrees. This is fine for fairly
+bright flares, but if you are looking for really dim ones (relative to
+the maximum brightness given the source of illumination) you want to
+increase this. The cost of increasing it is, of course, increased
+computation. The maximum useful value is the equivalent of 180 degrees,
+but this is not enforced. If you have a particular angle in mind, you
+will want to set this to about 10 degrees more, because of the way it is
+used in the flare algorithm.
+
 =item pm (boolean)
 
 If true, the flare() method returns flares that occur between evening
@@ -1546,6 +1587,29 @@ Technically, the default is 0. But if the object is manufactured by
 Astro::Coord::ECI::TLE->parse(), the status will be set based on the
 internal status table in Astro::Coord::ECI::TLE.
 
+=item zone (number)
+
+This attribute is used to determine whether a flare took place in the
+C<am> or C<pm>. It can be set to a number of possible values:
+
+* C<undef> causes the computation to be done in the local zone, whatever
+that is.
+
+* A numeric value is interpreted as an offset in hours east of
+Greenwich; hours west are negative.
+
+* Anything else is interpreted as a zone name; $ENV{TZ} is set to this,
+and then C<localtime()> is called. Whether this has the desired effect
+depends on your operating system.
+
+Yes, this is a bit of a crock, but I realized (B<after> putting out
+0.036, with the Iridium flare tests that anyone can run) that I needed
+to do B<something> to get a user's-zone-independent test. Eventually I
+may make use of DateTime if that is available, but I do not want to make
+that a prerequisite.
+
+The default is C<undef>.
+
 =back
 
 =head1 ACKNOWLEDGMENTS
@@ -1579,7 +1643,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2010, Thomas R. Wyant, III
+Copyright (C) 2005-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
